Page MenuHomePhabricator

cache-namespace.patch

Authored By
bzimport
Nov 21 2014, 10:57 PM
Size
2 KB
Referenced Files
None
Subscribers
None

cache-namespace.patch

Only in .: cache-namespace.patch
diff -ur ./ChangesFeed.php /var/www/mediawiki/includes/ChangesFeed.php
--- ./ChangesFeed.php 2009-02-14 16:00:51.000000000 +0000
+++ /var/www/mediawiki/includes/ChangesFeed.php 2009-12-15 14:51:07.000000000 +0000
@@ -18,7 +18,7 @@
$feedTitle, htmlspecialchars( $description ), $wgTitle->getFullUrl() );
}
- public function execute( $feed, $rows, $limit=0, $hideminor=false, $lastmod=false, $target='' ) {
+ public function execute( $feed, $rows, $limit=0, $hideminor=false, $namespace='', $lastmod=false, $target='' ) {
global $messageMemc, $wgFeedCacheTimeout;
global $wgSitename, $wgContLanguageCode;
@@ -27,7 +27,7 @@
}
$timekey = wfMemcKey( $this->type, $this->format, 'timestamp' );
- $key = wfMemcKey( $this->type, $this->format, $limit, $hideminor, $target );
+ $key = wfMemcKey( $this->type, $this->format, $limit, $hideminor, $namespace, $target );
FeedUtils::checkPurge($timekey, $key);
diff -ur ./specials/SpecialRecentchanges.php /var/www/mediawiki/includes/specials/SpecialRecentchanges.php
--- ./specials/SpecialRecentchanges.php 2009-05-01 07:59:04.000000000 +0100
+++ /var/www/mediawiki/includes/specials/SpecialRecentchanges.php 2009-12-15 14:54:58.000000000 +0000
@@ -67,8 +67,8 @@
public function feedSetup() {
global $wgFeedLimit, $wgRequest;
$opts = $this->getDefaultOptions();
- # Feed is cached on limit,hideminor; other params would randomly not work
- $opts->fetchValuesFromRequest( $wgRequest, array( 'limit', 'hideminor' ) );
+ # Feed is cached on limit,hideminor,namespace; other params would randomly not work
+ $opts->fetchValuesFromRequest( $wgRequest, array( 'limit', 'hideminor', 'namespace' ) );
$opts->validateIntBounds( 'limit', 0, $wgFeedLimit );
return $opts;
}
@@ -117,7 +117,7 @@
$target = isset($opts['target']) ? $opts['target'] : ''; // RCL has targets
if( $feedFormat ) {
list( $feed, $feedObj ) = $this->getFeedObject( $feedFormat );
- $feed->execute( $feedObj, $rows, $opts['limit'], $opts['hideminor'], $lastmod, $target );
+ $feed->execute( $feedObj, $rows, $opts['limit'], $opts['hideminor'], $opts['namespace'], $lastmod, $target );
} else {
$this->webOutput( $rows, $opts );
}

File Metadata

Mime Type
text/x-diff
Storage Engine
blob
Storage Format
Raw Data
Storage Handle
5977
Default Alt Text
cache-namespace.patch (2 KB)

Event Timeline